timeintervaltools.mask_intervals_with_intervals
===============================================

.. autofunction:: abjad.tools.timeintervaltools.mask_intervals_with_intervals.mask_intervals_with_intervals
